# -*- coding: utf-8 -*-
"""
第218回農林交流センターWS「メッシュ農業気象データ利用講習会」 
実習：Pythonによるメッシュ農業気象データの処理１

"""
#Pythonに機能を追加するために外部モジュールをインポートします。
import numpy as np               #配列計算を高速に実行するためのモジュール
import AMD_Tools3 as AMD         #メッシュ農業気象データを利用するためのモジュール



#ちょっと奇妙ですが、プログラムの本文は次の文で始めます。
if __name__ == "__main__":

    # 取得する気象要素の指定
    #  気象要素は、文字列で指定します。 
    nani = "TMP_mea"

    # データを取得する期間の指定
    #  2018年5月1日から9月30日までのデータを取得するには以下のように期間を指定します。
    itsu = ["2018-05-01", "2018-09-30" ]

    # 対象とする地点の指定
    #  北緯36.0566度,東経140.125度の地点を含むメッシュのデータを取得するには場所を以下のように指定します。
    doko = [ 36.0566, 36.0566, 140.125, 140.125]	#つくば(舘野)

    # 気象データの取得
    #　　気象データを取得するGetMetData関数の括弧の中に上記の変数を指定し、右辺に置きます。
    #　　左辺には関数の戻り値を置きます。順に、気象データ、日付、緯度、経度が格納されます。
    met, tim, lat, lon = AMD.GetMetData(nani, itsu, doko, url='./AMD')	#気象データを取得
    T = met[:,0,0]  #気象データは常に三次元(日付、緯度、経度)の入れ物に入れられて返されます。それを1次元(日付)の入れ物に入れ替えます。名前は一緒で構いません。
    ntim = len(tim)  #何日分の気象データかを数えます。
    
    #有効積算気温の計算
    Ts = 10.0              #基準温度
    Tccx = 950.0           #有効積算気温の上限値
    Tcc = np.zeros(ntim)   #有効積算気温の入れ物
    
    # 第１日目（０番目の配列要素）は特別扱いが必要です。
    Tcc[0] = 0                                                 #     <--------
    print("---", 0, tim[0], T[0], Tcc[0] )
    
    # 第２日目（１番目の配列要素）以降は繰り返し計算が可能です。
    for t in range(1, ntim):
        Tcc[t] = Tcc[t-1] + max(T[t]-Ts, 0.0)
        print("---", t, tim[t], T[t], Tcc[t] )
        if Tccx <= Tcc[t] :                  
            break                                      

    print()                                                  
    print(tim[t])                                          

"""
次を実行しましょう。
run aet3

練習問題４
　　　定植翌日からの有効積算気温が950℃で収穫適期を迎える農作物があったとします。
　　　この作物が2018年7月31日に収穫適期となるように栽培するには、何月何日に定植すればよいと見積も
　　　れるでしょう。プログラムaet3.pyを修正して、そのような定植日を表示させるプログラムを作成してください。
　　　なお、有効気温の基準温度は10℃とします。

ヒント    
    2018年3月1日から7月31日までのデータを取得する に変更する
    itsu = ["2018-03-01", "2018-07-31" ]

    この場合，tim[t], T[t]の並びは以下の通り
         　         0           1      ・・・      ntim-1     ntim(timの要素数)     
               tim[0]      tim[1]     ・・・  tim[ntim-1]   
                 T[0]        T[1]     ・・・    T[ntim-1]
     tim中身  2018-03-01  2018-03-02  ・・・    2018-07-31　
            
    2018年7月31日の有効積算気温が950℃(Tccx)であることを設定する
    Tcc[ntim-1]=Tccx 
                     
    for t in range(start,stop,step): range()は、数の並びのリスト
    startは、最初の数（デフォルトは0）、
     stopは、最後の数の次の数（例１、例２のデフォルトの場合は、データの個数）、
     stepは、ステップ数（デフォルトは1）                         
　例１　for t in range(5): print(t)      --> 0,1,2,3,4 
　例２ for t in range(0,5,1): print(t)  --> 0,1,2,3,4            
　例３ for t in range(1,5,1): print(t)  -->   1,2,3,4
　例４ for t in range(4,0,-1):print(t)  -->   4,3,2,1      
    
    for文のプロック内の，符号，変数，if文の条件式などを変更し，動作を確認しながら，修正していく  

<< Tips >>
    日時オブジェクトを文字列に変換するには以下のようにします。

    print("定植日は"+tim[t-1].strftime("%Y/%m/%d")+"です。") 


回答例が、aet4.pyに収めてあります。
aet4.pyを開きましょう。
"""


